////////////////////////////////////////////////////////////////////////////////
//
// gallery.js
//
/////////////////////////////////////////////////////////////////////////////////

var container_size = segment_size;
var selected_segment_number = 0;
var segment_index = -1;
var index_start = 0;

var images_selected;
var show_selected_only;
var all_selected_only = false;
var next_selected_only = false;

// Gallery config object
var config1 = {
  thumbnailId: 'thumb1',
  transitions: ['expand', 'crossfade']
};

open_gallery.initialized = false;
open_gallery.opened = false;

hs.Expander.prototype.onBeforeExpand = function (expander)
{
  var segment_number = Math.floor(segment_index / segment_size);
  var expander_id = expander.a.id;
  var button, i;

  if (expander_id == 'gallery_options')
  {
    g_options.clearAll = false;
    g_options.selectAll = false;
    g_options.clearInPageOnly = false;
    g_options.clearInAllPages = false;
    g_options.refreshHighlighting = false;
    g_options.refreshSelectedOnly = false;
    g_options.refreshImages = false;
    g_options.scaleImages = false;

    button = document.getElementById('scale');
    button.checked = scale_images;

    button = document.getElementById('highlight');
    button.checked = highlight_selections;

    button = document.getElementById('expand_view');
    button.checked = show_expanded_view;

    button = document.getElementById('image_names');
    button.checked = show_image_names;

    button = document.getElementById('show_selected');
    button.checked = all_selected_only;

    button = document.getElementById('next_selected');
    button.checked = next_selected_only;

    button = document.getElementById('select_all');
    button.checked = false;

    button = document.getElementById('clear_all');
    button.checked = false;

    if (last_segment > 1)
    {
      // clear image selection buttons
      button = document.getElementById('page_only');
      button.checked = false;

      button = document.getElementById('all_pages');
      button.checked = false;
    }
  }
}

////////////////////////////////////////////////////////////////////////////////
//
// initialize_gallery
//
/////////////////////////////////////////////////////////////////////////////////

function initialize_gallery()
{
  var images, segment_number;
  var style, e;
  var i;

  images_selected = new Array(last_segment);
  show_selected_only = new Array(last_segment);

  for (i = 0; i < last_segment; i++)
  {
    images_selected[i] = 0;
    show_selected_only[i] = false;
  }
  
  e = element('files');
  images = e.options;

  for (i = 0; i < images.length; i++)
  {
    segment_number = Math.floor(i / segment_size);

    if (images[i].selected)
      images_selected[segment_number] += 1;
  }

  for (i = 0; i < segment_size; i++)
  {
    e = element(stringN('check#', i));
    e.setAttribute('onclick', 'g_sel(this)');

    e = element(stringN('img#', i));
    e.setAttribute('onclick', 'return g_img_click(this)');

    if (scale_images)
    {
      e.setAttribute('width', image_width);
      e.setAttribute('height', image_height);
    }

    e = element(stringN('image#', i));
    e.setAttribute('onmouseout', 'g_img()');
    e.setAttribute('onmouseover', 'g_img(this)');
    e.setAttribute('onclick', 'return g_image_click(this)');
  }

  if (last_segment <= 1)
    return;

  style = 'cursor:pointer;visibility:hidden';

  e = element('prev_text');
  e.setAttribute('onclick', 'g_next(-1, 0)');
  e.style = style;
  
  e = element('next_text');
  e.setAttribute('onclick', 'g_next(1, 0)');
  e.style = style;

  if (visible_segments < last_segment)
  {
    e = element('left_arrow');
    e.setAttribute('onclick', stringN('g_next(-#)', visible_segments));
    e.style = style;
    
    e = element('right_arrow');
    e.setAttribute('onclick', stringN('g_next(#)', visible_segments));
    e.style = style;
  }

  style = 'cursor:pointer';

  for (i = 0; i < last_segment; i++)
  {
    if (i == visible_segments)
      style = 'cursor:pointer;display:none';

    e = element(stringN('g#',  i));
    e.innerHTML = stringN('&nbsp;#&nbsp;', i + 1);
    e.style = style;

    e.setAttribute('onmouseout', 'g_seg()');
    e.setAttribute('onmouseover', 'g_seg(this)');
    e.setAttribute('onclick', 'return g_load(this)');
  }

  refresh_page_numbers();
}

////////////////////////////////////////////////////////////////////////////////
//
// open_gallery
//
/////////////////////////////////////////////////////////////////////////////////

function open_gallery(thumb)
{
  var image_index, image_selected, image_name;
  var main_page, images_page, images_index;
  var images, image, anchor, open, close;
  var segment_number, selected_only;
  var count, i;

  open_gallery.thumb = thumb;
  
  if (open_gallery.opened)
    return close_gallery();

  if (open_gallery.initialized == false)
  {
    initialize_gallery();
    open_gallery.initialized = true;
  }
  
  images = document.getElementById('files').options;

  if (segment_index < 0)
  {
    if ((i = images.selectedIndex) >= 0)
      segment_index = Math.floor(i / segment_size) * segment_size;
    else
      segment_index = 0;

    segment_number = Math.floor(segment_index / segment_size);
    selected_segment_number = segment_number;

    if (last_segment > 1)
    {
      if (index_start > segment_number || segment_number >= index_start + visible_segments)
        g_next(segment_number - index_start);

      refresh_pages();
    }
  }
  else
    segment_number = Math.floor(segment_index / segment_size);

  thumb.href = orig_image_url + images[segment_index].value;

  // number of images in this segment
  count = Math.min(segment_size, images.length - segment_index);
  
  if (count < segment_size)
  {
    if (container_size == segment_size)
    {
      // hide excess segment elements
      for (i = count; i < segment_size; i++)
      {
        image = document.getElementById('i' + i);
        image.style.display = 'none';
      }
    }

    container_size = count;
  }
  else
  if (container_size < segment_size)
  {
    // restore hidden segment elements
    for (i = container_size; i < segment_size; i++)
    {
      image = document.getElementById('i' + i);
      image.style.display = '';
    }
    
    container_size = segment_size;
  }

  images_selected[segment_number] = 0;
  selected_only = show_selected_only[segment_number];

  for (i = 0; i < count; i++)
  {
    image_index = segment_index + i;
    image_name = images[image_index].value;
    image_selected = images[image_index].selected;
    
    anchor = document.getElementById('image' + i);
    anchor.href = orig_image_url + image_name;

    image = document.getElementById('img' + i);
    image.src = resized_image_url + image_name;

    checkbox = document.getElementById('check' + i);
    checkbox.checked = image_selected;
    
    image_border(image, checkbox.checked);

    image = document.getElementById('i' + i);
    image.style.display = (selected_only && !image_selected)? 'none' : '';

    if (image_selected)
      images_selected[segment_number]++;
  }

  main_page = document.getElementById('main_page');
  main_page.style.display = 'none';

  images_page = document.getElementById('images_page');
  images_page.style.display = '';

  if ((images_index = document.getElementById('images_index')) != null)
    images_index.style.display = '';

  document.getElementById('g_open').style.display = 'none';
  document.getElementById('g_close').style.display = '';

  open_gallery.opened = true;
  refresh_pages();

  return false;
}

////////////////////////////////////////////////////////////////////////////////
//
// close_gallery
//
/////////////////////////////////////////////////////////////////////////////////

function close_gallery()
{
  var images_index;

  document.getElementById('g_open').style.display = '';
  document.getElementById('g_close').style.display = 'none';

  reset_pages();

  if ((images_index = document.getElementById('images_index')) != null)
    images_index.style.display = 'none';
  
  document.getElementById('main_page').style.display = '';
  document.getElementById('images_page').style.display = 'none';

  open_gallery.opened = false;
  return false;
}

////////////////////////////////////////////////////////////////////////////////
//
// reset_pages
//
/////////////////////////////////////////////////////////////////////////////////

function reset_pages()
{
  if (last_segment > 1)
  {
    g_next(-index_start);

    index_start = 0;
    segment_index = -segment_size;
    selected_segment_number = 0;

    refresh_pages();
  }

  for (var i = 0; i < last_segment; i++)
  {
    images_selected[i] = 0;
    show_selected_only[i] = false;
  }
}

////////////////////////////////////////////////////////////////////////////////
//
// select_all_images  (in the current segment only)
//
/////////////////////////////////////////////////////////////////////////////////

function select_all_images()
{
  var images = document.getElementById('files').options;
  var image, checkbox;
  var index, count, i;

  // number of images in this segment
  count = Math.min(segment_size, images.length - segment_index);
  index = segment_index;

  for (i = 0; i < count; i++)
  {
    image = document.getElementById('img' + i);
    checkbox = document.getElementById('check' + i);

    checkbox.checked = true;
    images[index++].selected = true;
    image_border(image, true);

    image = document.getElementById('i' + i);
    image.style.display = '';
  }

  i = Math.floor(segment_index / segment_size);
  images_selected[i] = count;

  refresh_page_numbers(count);
}

////////////////////////////////////////////////////////////////////////////////
//
// clear_all_selections
//
/////////////////////////////////////////////////////////////////////////////////

function clear_all_selections()
{
  var images = document.getElementById('files').options;
  var segment_number, image, checkbox;
  var index, count, i;

  segment_number = Math.floor(segment_index / segment_size);
  selected_only = show_selected_only[segment_number];

  // number of images in this segment
  count = Math.min(segment_size, images.length - segment_index);
  index = segment_index;

  if (g_options.clearInPageOnly)
  {
    for (i = 0; i < count; i++)
    {
      image = document.getElementById('img' + i);
      checkbox = document.getElementById('check' + i);

      checkbox.checked = false;
      images[index++].selected = false;
      image_border(image, false);

      image = document.getElementById('i' + i);
      image.style.display = 'none';
    }
    
    i = Math.floor(segment_index / segment_size);
    show_selected_only[i] = false;
    images_selected[i] = 0;
  }
  else
  if (g_options.clearInAllPages)
  {
    for (i = 0; i < images.length; i++)
    {
      if (segment_index <= i && i < segment_index + count)
      {
        segment_number = i - segment_index;
        image = document.getElementById('img' + segment_number);
        checkbox = document.getElementById('check' + segment_number);

        checkbox.checked = false;
        image_border(image, false);

        if (selected_only)
        {
          image = document.getElementById('i' + segment_number);
          image.style.display = 'none';
        }
      }

      images[i].selected = false;
    }

    for (i = 0; i < last_segment; i++)
    {
      images_selected[i] = 0;
      show_selected_only[i] = false;
    }

    all_selected_only = false;
    next_selected_only = false;
  }

  refresh_images();
  refresh_pages();
}

////////////////////////////////////////////////////////////////////////////////
//
// selection_changed
//
/////////////////////////////////////////////////////////////////////////////////

function selection_changed(checkbox)
{
  var segment_number = Math.floor(segment_index / segment_size);
  var count = images_selected[segment_number];
  var i;

  count += checkbox.checked? 1 : -1;
  images_selected[segment_number] = count;

  if (last_segment > 1)
    refresh_page_numbers();
}

////////////////////////////////////////////////////////////////////////////////
//
// do_image_scaling
//
/////////////////////////////////////////////////////////////////////////////////

function do_image_scaling()
{
  var i, e;

  for (i = 0; i < segment_size; i++)
  {
    e = element(stringN('img#', i));

    if (scale_images)
    {
      e.setAttribute('width', image_width);
      e.setAttribute('height', image_height);
    }
    else
    {
      e.removeAttribute('width');
      e.removeAttribute('height');
    }
  }
}

////////////////////////////////////////////////////////////////////////////////
//
// refresh_images
//
/////////////////////////////////////////////////////////////////////////////////

function refresh_images()
{
  var images = document.getElementById('files').options;
  var image, checkbox, selected_only;
  var segment_number;
  var count, i;

  segment_number = Math.floor(segment_index / segment_size);
  selected_only = show_selected_only[segment_number];

  // number of images in this segment
  count = Math.min(segment_size, images.length - segment_index);

  for (i = 0; i < count; i++)
  {
    checkbox = document.getElementById('check' + i);
  
    if (g_options.refreshHighlighting)
    {
      image = document.getElementById('img' + i);
      
      if (highlight_selections)
        image_border(image, checkbox.checked);
      else
        image_border(image, false);
    }

    image = document.getElementById('i' + i);
    
    if (selected_only)
      image.style.display = checkbox.checked? '' : 'none';
    else
      image.style.display = '';
  }
}

////////////////////////////////////////////////////////////////////////////////
//
// refresh_pages
//
/////////////////////////////////////////////////////////////////////////////////

function refresh_pages()
{
  var segment, segment_number;
  var i;
  
  if (last_segment > 1)
  {
    var prev_text = document.getElementById('prev_text');
    var next_text = document.getElementById('next_text');

    if (next_selected_only)
    {
      segment_number = Math.floor(segment_index / segment_size);
      
      for (i = segment_number - 1; i >= 0; i--)
      {
        if (images_selected[i] > 0)
          break;
      }

      prev_text.style.visibility = i >= 0? 'visible' : 'hidden';
      
      for (i = segment_number + 1; i < last_segment; i++)
      {
        if (images_selected[i] > 0)
          break;
      }
      
      next_text.style.visibility = i < last_segment? 'visible' : 'hidden';
    }
    else
    {
      segment_number = Math.floor(segment_index / segment_size) + 1;

      prev_text.style.visibility = segment_number > 1? 'visible' : 'hidden';
      next_text.style.visibility = segment_number < last_segment? 'visible' : 'hidden';
    }

    if (visible_segments < last_segment)
    {
      var prev_arrow = document.getElementById('left_arrow');
      var next_arrow = document.getElementById('right_arrow');

      prev_arrow.style.visibility = index_start > 0? 'visible' : 'hidden';
      next_arrow.style.visibility = index_start + visible_segments < last_segment? 'visible' : 'hidden';
    }

    for (i = 0; i < last_segment; i++)
    {
      segment = document.getElementById('g' + i);
      segment.style.fontWeight = 'normal';
      segment.style.color = '';
      
      if (i >= index_start && i < index_start + visible_segments)
      {
        var border = '1px solid black';
        segment.style.border = i == selected_segment_number? border : '';
        segment.style.display = '';
      }
      else
        segment.style.display = 'none';
    }

    refresh_page_numbers();
  }
}

////////////////////////////////////////////////////////////////////////////////
//
// refresh_page_numbers
//
/////////////////////////////////////////////////////////////////////////////////

function refresh_page_numbers(count)
{
  var i = Math.floor(segment_index / segment_size);

  if (arguments.length == 1)
    images_selected[i] = count;

  if (last_segment > 1)
  {
    for (i = 0; i < last_segment; i++)
    {
      var segment = document.getElementById('g' + i);
  
      if (images_selected[i] > 0)
      {
        segment.style.color = 'red';
        segment.style.fontWeight = 'bold';
      }
      else
      {
        segment.style.color = '';
        segment.style.fontWeight = '';
      }
    }
  }
}

////////////////////////////////////////////////////////////////////////////////
//
// g_options
//
/////////////////////////////////////////////////////////////////////////////////

function g_options(option)
{
  var expander;
  var i;

  switch (option.id)
  {
    case 'highlight':
      highlight_selections = !highlight_selections;
      g_options.refreshHighlighting = true;
      g_options.refreshImages = true;
      break;

    case 'scale':
      scale_images = !scale_images;
      g_options.scaleImages = true;
      break;
    
    case 'image_names':
      show_image_names = !show_image_names;
      break;
    
    case 'expand_view':
      show_expanded_view = !show_expanded_view;
      break;

    case 'show_selected':
      all_selected_only = !all_selected_only;
      for (i = 0; i < last_segment; i++)
        show_selected_only[i] = all_selected_only;
      g_options.refreshImages = true;
      g_options.refreshSelectedOnly = true;
      break;

    case 'next_selected':
      next_selected_only = !next_selected_only;
      g_options.refreshSelectedOnly = true;
      break;

    case 'select_all':
      g_options.clearAll = false;
      g_options.selectAll = true;
      g_options.clearInPageOnly = false;
      g_options.clearInAllPages = false;
      document.getElementById('clear_all').checked = false;
      document.getElementById('page_only').checked = false;
      document.getElementById('all_pages').checked = false;
      break;

    case 'clear_all':
      g_options.clearAll = true;
      g_options.selectAll = false;
      g_options.clearInPageOnly = true;
      g_options.clearInAllPages = false;
      document.getElementById('page_only').checked = true;
      document.getElementById('all_pages').checked = false;
      document.getElementById('select_all').checked = false;
      break;

    case 'page_only':
      g_options.clearAll = true;
      g_options.selectAll = false;
      g_options.clearInPageOnly = true;
      g_options.clearInAllPages = false;
      document.getElementById('clear_all').checked = true;
      document.getElementById('all_pages').checked = false;
      document.getElementById('select_all').checked = false;
      break;

    case 'all_pages':
      g_options.clearAll = true;
      g_options.selectAll = false;
      g_options.clearInPageOnly = false;
      g_options.clearInAllPages = true;
      document.getElementById('clear_all').checked = true;
      document.getElementById('page_only').checked = false;
      document.getElementById('select_all').checked = false;
      break;

    case 'do_options':
      if (g_options.scaleImages)
        do_image_scaling();

      if (g_options.selectAll)
        select_all_images();

      if (g_options.clearAll)
        clear_all_selections();

      if (g_options.refreshImages)
        refresh_images();

      if (g_options.refreshSelectedOnly)
        refresh_pages();

      expander = hs.getExpander('gallery_options');
      expander.close();
      break;
  }
}

////////////////////////////////////////////////////////////////////////////////
//
// g_load
//
/////////////////////////////////////////////////////////////////////////////////

function g_load(segment)
{
  var thumb = document.getElementById('thumb1');
  var segment_number;

  if (typeof(segment) == 'number')
    segment_number = segment;
  else
    segment_number = segnum(segment);

  if (segment_number == selected_segment_number)
  {
    show_selected_only[segment_number] = !show_selected_only[segment_number];
    refresh_images();
    return false;
  }

  segment_index = segment_number * segment_size;
  selected_segment_number = segment_number;

  if (segment_number < index_start)
  {
    var i = segment_number - visible_segments + 1;
    g_next(i - index_start);
  }
  else
  if (segment_number >= index_start + visible_segments)
  {
    g_next(segment_number - index_start);
  }

  refresh_pages();

  // virtually closed for this segment
  open_gallery.opened = false;

  return open_gallery(thumb);
}

////////////////////////////////////////////////////////////////////////////////
//
// g_next
//
/////////////////////////////////////////////////////////////////////////////////

function g_next(increment)
{
  var segment_number;

  // The arguments length is used to determine which next function to perform
  // but only the first argument is actually used.

  if (arguments.length == 2)
  {
    if (next_selected_only)
    {
      var images = document.getElementById('files').options;
      var load_segment = -1;
      var more = false;

      segment_number = Math.floor(segment_index / segment_size);
      segment_number += increment;
      
      // find the next segment with images selected
      while (segment_number >= 0 && segment_number < last_segment)
      {
        if (images_selected[segment_number] > 0)
        {
          if (load_segment < 0)
            load_segment = segment_number;
          else
            more = true;
        }
        
        segment_number += increment;
      }

      if (load_segment >= 0)
        g_load(load_segment);

      if (more == false)
      {
        var text = increment < 0? 'prev_text' :'next_text';
        document.getElementById(text).style.visibility = 'hidden';
      }
    }
    else
    {
      // load the next contiguous segment
      segment_number = Math.floor(segment_index / segment_size);
      segment_number += increment;
      segment_number = Math.max(segment_number, 0);
      segment_number = Math.min(segment_number, last_segment);
      g_load(segment_number);
    }
  }
  else
  {
    // the left or right arrow was clicked to scroll the page numbers
    index_start += increment;
    index_start = Math.max(index_start, 0);
    index_start = Math.min(index_start, last_segment);
    refresh_pages();
  }
}

////////////////////////////////////////////////////////////////////////////////
//
// g_seg
//
/////////////////////////////////////////////////////////////////////////////////

function g_seg(segment)
{
  if (arguments.length > 0)
  {
    var images = document.getElementById('files').options;
    var segment_number = segnum(segment);
    var index = segment_number * segment_size;
    var image = images[index].text;
    var count, i;
    
    if (last_segment > 1 && show_selected_only)
    {
      if (images_selected[segment_number] > 0)
      {
        // number of images in this segment
        count = Math.min(segment_size, images.length - index);

        for (i = 0; i < count; i++, index++)
        {
          if (images[index].selected)
          {
            image = images[index].text;
            break;
          }
        }
      }
    }

    tooltip_name(image);
  }
  else
    hideddrivetip();
}

////////////////////////////////////////////////////////////////////////////////
//
// g_img
//
/////////////////////////////////////////////////////////////////////////////////

function g_img(anchor)
{
  if (arguments.length > 0)
  {
    var url = anchor.href;
    var image = url.slice(url.lastIndexOf('/') + 1);
    
    if (show_image_names)
      tooltip_name(image);
  }
  else
    hideddrivetip();
}

////////////////////////////////////////////////////////////////////////////////
//
// g_sel
//
/////////////////////////////////////////////////////////////////////////////////

function g_sel(checkbox)
{
  var images = document.getElementById('files').options;
  var segment_number = Math.floor(segment_index / segment_size);
  var i;

  if ((i = checkbox.id.search(/[0123456789]+/)) > 0)
  {
    var image_num = Number(checkbox.id.slice(i));
    var image = images[segment_index + image_num];
    image.selected = checkbox.checked;
    
    image = document.getElementById('img' + image_num);
    image_border(image, checkbox.checked);

    if (show_selected_only[segment_number] && !checkbox.checked)
    {
      image = document.getElementById('i' + image_num);
      image.style.display = 'none';
    }

    selection_changed(checkbox);
  }
}

////////////////////////////////////////////////////////////////////////////////
//
// g_chk
//
/////////////////////////////////////////////////////////////////////////////////

function g_chk(image)
{
  var i;
  
  if ((i = image.id.search(/[0123456789]+/)) > 0)
  {
    var image_num = Number(image.id.slice(i));
    var checkbox = document.getElementById('check' + image_num);

    checkbox.checked = !checkbox.checked;
    g_sel(checkbox);
  }

  return false;
}

////////////////////////////////////////////////////////////////////////////////
//
// g_image_click
//
/////////////////////////////////////////////////////////////////////////////////

function g_image_click(image)
{
  var i;

  if (show_expanded_view)
  {
    if ((i = image.id.search(/[0123456789]+/)) > 0)
    {
      var image_num = Number(image.id.slice(i));
      return hs.expand(image, {thumbnailId: 'img' + image_num} );
    }
  }
  else
    return false;
}

////////////////////////////////////////////////////////////////////////////////
//
// g_img_click
//
/////////////////////////////////////////////////////////////////////////////////

function g_img_click(image)
{
  if (!show_expanded_view)
    return g_chk(image);
  else
    return false;
}

////////////////////////////////////////////////////////////////////////////////
//
// image_border
//
/////////////////////////////////////////////////////////////////////////////////

function image_border(image, selected)
{
  var color, width, style;

  if (selected && highlight_selections)
  {
    var parts = gallery_image_border.split(';');
    width = parts[0];
    style = parts[1];
    color = parts[2];
  }
  else
  {
    width = '0px';
    style = '';
    color = '';
  }

  image.style.borderColor = color;
  image.style.borderWidth = width;
  image.style.borderTopStyle = style;
  image.style.borderLeftStyle = style;
  image.style.borderRightStyle = style;
  image.style.borderBottomStyle = style;
}

////////////////////////////////////////////////////////////////////////////////
//
// tooltip_name
//
/////////////////////////////////////////////////////////////////////////////////

function tooltip_name(name)
{
  var parts, part1, part2;

  parts = name.split(' ');
  name = parts[0];

  if (name.length > 35)
  {
    var i = name.lastIndexOf('_');

    if (i < 0)
      i = name.lastIndexOf('-');

    if (i < 0)
      i = 32;

    part1 = name.substr(0, i);
    part2 = name.substr(i + 1);
    name = part1 + ' ' + part2;
  }

  ddrivetip(name, '#EFEFEF');
}

////////////////////////////////////////////////////////////////////////////////
//
// show_option_note
//
/////////////////////////////////////////////////////////////////////////////////

function show_option_note(show)
{
  var note = document.getElementById('option_note');
  var plus = document.getElementById('option_note_plus');
  var minus = document.getElementById('option_note_minus');

  if (show)
  {
    note.style.display = '';
    plus.style.display = 'none';
    minus.style.display = '';
  }
  else
  {
    note.style.display = 'none';
    plus.style.display = '';
    minus.style.display = 'none';
  }
}

////////////////////////////////////////////////////////////////////////////////
//
// element
//
/////////////////////////////////////////////////////////////////////////////////

function element(id)
{
  return document.getElementById(id);
}

////////////////////////////////////////////////////////////////////////////////
//
// segnum
//
/////////////////////////////////////////////////////////////////////////////////

function segnum(segment)
{
  var i = segment.id.search(/[0123456789]+/);
  return Number(segment.id.slice(i));
}

////////////////////////////////////////////////////////////////////////////////
//
// stringN
//
/////////////////////////////////////////////////////////////////////////////////

function stringN(string, i)
{
  var parts = string.split('#');
  return parts[0] + i + parts[1];
}


/************************************************************************************
/*
/*  Settings used for the image viewer
/*
/************************************************************************************

// These header settings are used to display the image name and size in the gallery.
hs.headingOverlay.position = "top";
hs.headingOverlay.width = "100%";
hs.headingOverlay.opacity = .75;
hs.headingOverlay.hideOnMouseOut = true;

// This string is used to display the image sequence number, the image name, and a checkbox for
// selecting an image in the gallery.
hs.lang.number = '<label><input id="check_%1" type=checkbox onclick="select_image(this)">&nbsp;' +
    gallery_image_number + '</label><p><span id=\"name_%1\" style="color:black"></span><br>';

// Note: To allow any number of '%1' replacements in the above string, the getNumber()
// function in highslide.js was modified as follows:
// var s = hs.lang.number.replace('%1', this.getAnchorIndex() + 1).replace('%2', arr.length);
// to
// var s = hs.lang.number.replace(/%1/g, this.getAnchorIndex() + 1).replace('%2', arr.length);

  var expander_id = expander.a.id;

  if (expander_id.match(/image[0123456789]+/))
  {
    var images = document.getElementById('files').options;
    var i;

    if ((i = expander_id.search(/[0123456789]+/)) > 0)
    {
      var image_num = Number(expander_id.slice(i));
      var image_name = document.getElementById('name_' + image_num);
      var checkbox = document.getElementById('check_' + image_num);
      var index = segment_index + image_num - 1;
      var image = images[index];
    
      image_name.innerText = image.value;
      checkbox.checked = image.selected;
    }    
  }
*/

