
function check_canada_post_config()
{
  if (check_weight('canada_post_max_pkg_weight') == false)
    return false;

  if (check_weight('canada_post_min_weight', 'canada_post_use_min_weight') == false)
    return false;

  if (check_weight('canada_post_min_order_weight', 'canada_post_use_min_order_weight') == false)
    return false;

  if (check_rate_percent('canada_post_commercial_rate_adjust') == false)
    return false;

  if (check_rate_percent('canada_post_counter_rate_adjust') == false)
    return false;

  if (check_proof_of_age() == false)
    return false;

  if (check_rate_type() == false)
    return false;

  if (check_max_pkg_size() == false)
    return false;

  if (check_reserve_pkg_size() == false)
    return false;

  if (check_min_item_size() == false)
    return false;

  return true;
}

function check_weight(weight_id, use_id)
{
  var weight_elem = document.getElementById(weight_id);
  var weight_entered = weight_elem.value.length > 0;

  if (arguments.length > 1)
  {
    if (document.getElementById(use_id).checked)
    {
      if (!weight_entered)
      {
        weight_elem.focus();
        alert(enter_weight);
        return false;
      }
    }
  }

  if (isNaN(weight_elem.value))
  {
    weight_elem.focus();
    alert(weight_not_a_number);
    return false;
  }

  if (weight_entered && Number(weight_elem.value) <= 0)
  {
    weight_elem.focus();
    alert(invalid_weight);
    return false;
  }

  return true;
}

function check_rate_percent(percent_id)
{
  var percent_elem = document.getElementById(percent_id);
  var percent = percent_elem.value;

  if (percent.length > 0)
  {
    percent = Number(percent);
    if (isNaN(percent))
    {
      percent_elem.focus();
      alert(percent_not_a_number);
      return false;
    }
  }

  return true;
}

function check_max_pkg_size()
{
  var l = document.getElementById('canada_post_max_pkg_length');
  var w = document.getElementById('canada_post_max_pkg_width');
  var h = document.getElementById('canada_post_max_pkg_height');

  return check_dimensions(l, w, h);
}  

function check_reserve_pkg_size()
{
  var l = document.getElementById('canada_post_packing_material_length');
  var w = document.getElementById('canada_post_packing_material_width');
  var h = document.getElementById('canada_post_packing_material_height');

  return check_dimensions(l, w, h);
}  

function check_min_item_size()
{
  var l = document.getElementById('canada_post_min_item_length');
  var w = document.getElementById('canada_post_min_item_width');
  var h = document.getElementById('canada_post_min_item_height');

  if (document.getElementById('canada_post_use_min_item_size').checked)
  {
    if (l.value.length == 0 && w.value.length == 0 && h.value.length == 0)
    {
      l.focus();
      alert(enter_dimensions);
      return false;
    }
  }

  return check_dimensions(l, w, h);
}  

function check_proof_of_age()
{
  var proof_of_age = document.getElementById('proof_of_age').checked;
  var pa18 = document.getElementById('pa18').checked;
  var pa19 = document.getElementById('pa19').checked;

  if (proof_of_age)
  {
    if (!(pa18 || pa19))
    {
      alert(select_age_required);
      return false;
    }
  }

  return true;
}

function check_rate_type()
{
  var name = 'canada_post_rates';
  var counter = document.getElementById(name + '.ct');
  var commercial = document.getElementById(name + '.cm');

  if (commercial.checked && contract == false)
  {
    commercial.focus();
    alert(contract_number_required);
    commercial.checked = false;
    counter.checked = true;
    return false;
  }

  return true;
}

function signature_required_option()
{
  var signature = document.getElementById('signature_required').checked;
  var proof_of_age = document.getElementById('proof_of_age').checked;

  if (signature || proof_of_age)
  {
    var non = document.getElementById('delivery_option_none');
    var hfp = document.getElementById('delivery_option_hfp');
    var lad = document.getElementById('delivery_option_lad');
    var dns = document.getElementById('delivery_option_dns');

    lad.checked = false;
    
    if (proof_of_age)
      dns.checked = false;

    if (!(hfp.checked || dns.checked))
      non.checked = true;
  }
  
  if (!proof_of_age)
  {
    document.getElementById('pa18').checked = false;
    document.getElementById('pa19').checked = false;
  }
}

function age_required_option()
{
  var pa18 = document.getElementById('pa18').checked;
  var pa19 = document.getElementById('pa19').checked;

  if (pa18 || pa19)
  {
    document.getElementById('proof_of_age').checked = true;
    signature_required_option();
  }
}

function leave_at_door(button)
{
  var signature = document.getElementById('signature_required').checked;
  var proof_of_age = document.getElementById('proof_of_age').checked;

  if (signature || proof_of_age)
  {
    alert(lad_not_allowed);
    document.getElementById('delivery_option_none').checked = true;
    button.checked = false;
  }
}

function do_not_safe_drop(button)
{
  var proof_of_age = document.getElementById('proof_of_age').checked;

  if (proof_of_age)
  {
    alert(dns_not_allowed);
    document.getElementById('delivery_option_none').checked = true;
    button.checked = false;
  }
}

function expand_format_codes()
{
  var format_codes = document.getElementById('format_codes');
  var image = document.getElementById('show_format_codes');
  var display = format_codes.style.display;
  var i = image.src.lastIndexOf('/') + 1;

  if (display == 'none')
  {
    format_codes.style.display = '';
    image.src = image.src.slice(0, i) + 'minus.gif';
  }
  else
  {
    format_codes.style.display = 'none';
    image.src = image.src.slice(0, i) + 'plus.gif';
  }
}

function expand_extension_note()
{
  var extension_note = document.getElementById('extension_note');
  var image = document.getElementById('show_extension_note');
  var display = extension_note.style.display;
  var i = image.src.lastIndexOf('/') + 1;

  if (display == 'none')
  {
    extension_note.style.display = '';
    image.src = image.src.slice(0, i) + 'minus.gif';
  }
  else
  {
    extension_note.style.display = 'none';
    image.src = image.src.slice(0, i) + 'plus.gif';
  }
}

